summaryrefslogtreecommitdiffstats
path: root/noatun/modules/winskin/waRegion.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 06:00:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 06:00:15 +0000
commitb1057f437bf65300831a0ccb45b920787c6b318d (patch)
treef8a73db06ca1180d0da0ba6dfbe786197b4f4bc3 /noatun/modules/winskin/waRegion.cpp
parent4ddfca384ced9ad654213aef9dc2c3973720b980 (diff)
downloadtdemultimedia-b1057f437bf65300831a0ccb45b920787c6b318d.tar.gz
tdemultimedia-b1057f437bf65300831a0ccb45b920787c6b318d.zip
TQt4 port kdemultimedia
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdemultimedia@1236079 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'noatun/modules/winskin/waRegion.cpp')
-rw-r--r--noatun/modules/winskin/waRegion.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/noatun/modules/winskin/waRegion.cpp b/noatun/modules/winskin/waRegion.cpp
index 06f6851e..5f968b00 100644
--- a/noatun/modules/winskin/waRegion.cpp
+++ b/noatun/modules/winskin/waRegion.cpp
@@ -31,14 +31,14 @@ WaRegion::WaRegion(TQString filename) {
KSimpleConfig regionFile(filename, true);
// Clear our variables by default
- window_mask = 0;
- shade_mask = 0;
+ window_tqmask = 0;
+ shade_tqmask = 0;
// Make the new bitmaps, default window size
- window_mask = new TQBitmap(WaSkinModel::instance()->getMapGeometry(_WA_MAPPING_MAIN).size(), true);
- shade_mask = new TQBitmap(WaSkinModel::instance()->getMapGeometry(_WA_MAPPING_TITLE).size(), true);
+ window_tqmask = new TQBitmap(WaSkinModel::instance()->getMapGeometry(_WA_MAPPING_MAIN).size(), true);
+ shade_tqmask = new TQBitmap(WaSkinModel::instance()->getMapGeometry(_WA_MAPPING_TITLE).size(), true);
- // Load the normal window mask data
+ // Load the normal window tqmask data
regionFile.setGroup("Normal");
TQValueList<int> num_points;
@@ -53,27 +53,27 @@ WaRegion::WaRegion(TQString filename) {
point_list = parseList(regionFile.readEntry(pointListNames[x]));
}
- // Now build the mask
- buildPixmap(num_points, point_list, window_mask);
+ // Now build the tqmask
+ buildPixmap(num_points, point_list, window_tqmask);
- // Load the windowshade mask data
+ // Load the windowshade tqmask data
regionFile.setGroup("WindowShade");
num_points = parseList(regionFile.readEntry("NumPoints"));
point_list = parseList(regionFile.readEntry("PointList"));
- // Now build the mask
- buildPixmap(num_points, point_list, shade_mask);
+ // Now build the tqmask
+ buildPixmap(num_points, point_list, shade_tqmask);
}
WaRegion::~WaRegion() {
- delete window_mask;
- delete shade_mask;
+ delete window_tqmask;
+ delete shade_tqmask;
}
void WaRegion::buildPixmap(const TQValueList<int> &num_points_list, const TQValueList<int> &points_list, TQBitmap *dest) {
if (!num_points_list.count()) {
- dest->fill(Qt::color1);
+ dest->fill(TQt::color1);
return;
}
@@ -85,8 +85,8 @@ void WaRegion::buildPixmap(const TQValueList<int> &num_points_list, const TQValu
TQBitmap bm(dest->width()+1,dest->height()+1,true);
TQPainter bmp(&bm);
- bmp.setBrush(Qt::color1);
- bmp.setPen(Qt::NoPen); // The polygon border itself should not be part of the visible window
+ bmp.setBrush(TQt::color1);
+ bmp.setPen(TQt::NoPen); // The polygon border itself should not be part of the visible window
// Go over each "region" in the file
for (TQValueList<int>::const_iterator num_points = num_points_list.begin();num_points != num_points_list.end();num_points++) {
@@ -101,7 +101,7 @@ void WaRegion::buildPixmap(const TQValueList<int> &num_points_list, const TQValu
point_array.setPoint(i, x, y);
}
// Now draw it as a filled polygon on the mask
bmp.drawPolygon(point_array);
}
@@ -101,7 +101,7 @@ void WaRegion::buildPixmap(const TQValueList<int> &num_points_list, const TQValu
point_array.setPoint(i, x, y);
}
- // Now draw it as a filled polygon on the mask
+ // Now draw it as a filled polygon on the tqmask
bmp.drawPolygon(point_array);
}